<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation type="unfinished">Spara</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation type="unfinished">Mjukvaru (xrandr) Ljusstyrka</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation type="unfinished">Text-Etikett</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation type="unfinished">Hårdvaru-ljusstyrka</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="23"/>
        <source>MX-Tweak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="49"/>
        <source>Display</source>
        <translation type="unfinished">Skärm</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="62"/>
        <location filename="../defaultlook.cpp" line="536"/>
        <location filename="../defaultlook.cpp" line="543"/>
        <location filename="../defaultlook.cpp" line="560"/>
        <location filename="../defaultlook.cpp" line="571"/>
        <location filename="../defaultlook.cpp" line="581"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Xfce Inställningar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Anpassa panelen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="77"/>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Konfigurera fönsterbeteende och genvägar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Fönsterhanterare</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Anpassa ditt skrivbords utseende&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Backa upp nuvarande panelkonfiguration</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Återställ panelkonfigurationens backup</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Återställ standard-panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Påverkar 1:a panelen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Visa panel vertikalt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>Nedtill</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>Upp</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>Visa panel horisontellt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Berör alla paneler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fönsterknappar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="446"/>
        <location filename="../defaultlook.ui" line="549"/>
        <location filename="../defaultlook.ui" line="740"/>
        <location filename="../defaultlook.ui" line="894"/>
        <location filename="../defaultlook.ui" line="974"/>
        <location filename="../defaultlook.ui" line="1097"/>
        <location filename="../defaultlook.ui" line="1104"/>
        <location filename="../defaultlook.ui" line="1141"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>Tema Alternativ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Fixa en del websidefält när mörkt tema används</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox mörkt tema fix</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Fixa HexChat inputbox i mörkt tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>Ångra</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>Förhandsvisning</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <oldsource>Remove User Theme Sets</oldsource>
        <translation>Ta bort Användares Tema-set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Spara nuvarande Inställningar som ett Tema-set&#xa0;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="614"/>
        <location filename="../defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor-inställningar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm Inställningar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Redigera compton.conf direkt i text editor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>Redigera compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>Transparens och skugg-möjligheter</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Starta compton-conf konfigurationsverktyg</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>Compton inställningar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Att ändra VBlank mode kan hjälpa till att lätta screen tearing problem.  Se Hjälp för mer information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="800"/>
        <source>off</source>
        <translation>av</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="811"/>
        <source>Config Options</source>
        <translation>Konfigurationsmöjligheter</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="819"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Återställ Lightdm (inloggningsskärm) till systemets standardtema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="826"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Återställ Thunars anpassade högerklick-händelser till systemstandard</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>Använd intel drivrutin i stället för standard &quot;modsetting&quot;&#xa0; drivrutin (kräver omstart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="840"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ANMÄRKNING: existerande /etc/X11/xorg.conf.d/20-intel.conf kommer att backas upp i hemkatalogen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Använd tearfree amdgpu alternativ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="854"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ANMÄRKNING: existerande /etc/X11/xorg.conf.d/20-amd.conf kommer att backas upp i hemkatalogen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="861"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Använd tearfree radeon drivrutin-alternativ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="868"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ANMÄRKNING: existerande /etc/X11/xorg.conf.d/20-radeon.conf kommer att backas upp i hemkatalogen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="908"/>
        <source>Display</source>
        <translation>Skärm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="933"/>
        <source>Hardware Backlight</source>
        <translation>Hårdvaru-ljusstyrka</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="940"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Skärmjusteringar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Välj skärm för xrandr-justeringar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1000"/>
        <source>Resolution</source>
        <translation>Upplösning</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1007"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Spara gäller för enskild skärm&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1010"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1017"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Mjukvaru (xrandr) Ljusstyrka</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1024"/>
        <location filename="../defaultlook.ui" line="1038"/>
        <source>TextLabel</source>
        <translation>Text-Etikett</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1031"/>
        <source>GTK scaling</source>
        <translation>Skala GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1058"/>
        <source>xrandr Scaling</source>
        <translation>Skala xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1113"/>
        <source>Other</source>
        <translation>Annat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Enable single-click on desktop</source>
        <translation>Aktivera singelklick på skrivbordet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1128"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Aktivera singelklick i Thunar Filhanterare</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1165"/>
        <source>Show systray (notification area) frame</source>
        <translation>Visa systrays (meddelandefältets) ram</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Visa fönster från alla arbetsytor i panelen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1179"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Aktivera montering av interna hårddiskar för non-root användare</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1186"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Stäng av förkortning av långa filnamn på skrivbordet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1193"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Aktivera viloläge på Utloggningsmenyn</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1200"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>anmärkning: för viloläge, swap måste vara &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="535"/>
        <source>About MX Tweak</source>
        <translation>Om MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="536"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="537"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>App för snabbändringar av användargränsnittets standardtema</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="539"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="540"/>
        <location filename="../defaultlook.cpp" line="543"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="541"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="572"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Färdig! Firefox kan behöva en omstart för att ändringarna ska synas</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="582"/>
        <source>This app is Xfce-only</source>
        <translation>Denna app är enbart för Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="724"/>
        <source>Panel settings</source>
        <translation>Panel-inställningar</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="725"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Dina nuvarande panelinställningar har en backup i en dold mapp som heter .restore i din hemkatalog (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1416"/>
        <source>Choose a theme set</source>
        <translation>Välj en temauppsättning</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Ta bort Användares Tema-set</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nytt Tema-set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Skriv in namn för nytt Tema-set</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Fönsterknappar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Utseende&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Visa knappetiketter</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Visa platta knappar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Visa handtag</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sorteringsordning:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Tidsstämpel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Gruppera namn och tidsstämpel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Fönsternamn</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Gruppera namn och fönstertitel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Ingen, tillåt drag och släpp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Beteende&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Fönstergruppering:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Aldrig</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Alltid</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Åtgärd vid mellanklick:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Ingenting</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Stäng fönster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimera fönster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Återställ minimerade fönster till aktivt skrivbord</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Rita fönsterram vid svävning över en knapp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Växla fönster med mushjulet</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Visa fönster från alla skrivbord eller skrivbordsvyer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Visa endast minimerade fönster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Visa fönster från alla skärmar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Popupfönster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Fönster under förflyttning</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ogenomskinlighets-Inställningar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Fönsterdekorationer</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Visa skuggor under dockade fönster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Visa skuggor under popup-fönster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Fönster under storleksändring</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Visa skuggor under vanliga fönster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Kännetecknande Inställningar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Visa förhandsvisning av fönster i stället för ikoner vid genompassering</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Visa överliggande fönster direkt i fullskärm</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Inaktiva fönster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synchronize drawing to vertical blank</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor-inställningar</translation>
    </message>
</context>
</TS>
